@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for BIMI
-our $VERSION = '3.20230911'; # VERSION
+our $VERSION = '3.20240205'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
-use Mail::BIMI 2;
+use Mail::BIMI 3.20230913;
 
 sub default_config {
     return {
@@ -307,15 +307,20 @@ sub eom_callback {
                     $self->add_auth_header( $AuthResults );
                     $self->{ 'header_added' } = 1;
                     my $Record = $BIMI->record();
+                    my $is_experimental = 'none';
+                    my $mark_type = 'none';
                     if ( $Result->result() eq 'pass' ) {
                         my $Headers = $Result->headers;
                         if ( $Headers ) {
                             $self->prepend_header( 'BIMI-Location', $Headers->{'BIMI-Location'} ) if exists $Headers->{'BIMI-Location'} ;
                             $self->prepend_header( 'BIMI-Indicator', $Headers->{'BIMI-Indicator'} ) if exists $Headers->{'BIMI-Indicator'} ;
                         }
+                        $is_experimental = eval{ $AuthResults->search({ 'isa' => 'subentry', 'key' => 'policy.experimental' })->children()->[0]->value() } // 'no';
+                        $self->handle_exception($@);
+                        $mark_type = eval{ $AuthResults->search({ 'isa' => 'subentry', 'key' => 'policy.mark-type' })->children()->[0]->value() } // 'unknown';
+                        $self->handle_exception($@);
                     }
-
-                    $self->metric_count( 'bimi_total', { 'result' => $Result->result() } );
+                    $self->metric_count( 'bimi_total', { 'result' => $Result->result(), 'is_experimental' => $is_experimental, 'mark_type' => $mark_type } );
                 }
                 $BIMI->finish;
             }
@@ -356,7 +361,7 @@ Mail::Milter::Authentication::Handler::BIMI - Handler class for BIMI
 
 =head1 VERSION
 
-version 3.20230911
+version 3.20240205
 
 =head1 DESCRIPTION
 
